==> kubernetes-model-kustomize-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/VarFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VarFluentImpl<A extends VarFluent<A>> extends BaseFluent<A> implements VarFluent<A>{
  public VarFluentImpl() {
  }
  public VarFluentImpl(Var instance) {
    this.withFieldref(instance.getFieldref()); 
    this.withName(instance.getName()); 
    this.withObjref(instance.getObjref()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private FieldSelectorBuilder fieldref;
  private String name;
  private TargetBuilder objref;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildFieldref instead.
   * @return The buildable object.
   */
  @Deprecated
  public FieldSelector getFieldref() {
    return this.fieldref!=null ?this.fieldref.build():null;
  }
  public FieldSelector buildFieldref() {
    return this.fieldref!=null ?this.fieldref.build():null;
  }
  public A withFieldref(FieldSelector fieldref) {
    _visitables.get("fieldref").remove(this.fieldref);
    if (fieldref!=null){ this.fieldref= new FieldSelectorBuilder(fieldref); _visitables.get("fieldref").add(this.fieldref);} else { this.fieldref = null; _visitables.get("fieldref").remove(this.fieldref); } return (A) this;
  }
  public Boolean hasFieldref() {
    return this.fieldref != null;
  }
  public A withNewFieldref(String fieldPath) {
    return (A)withFieldref(new FieldSelector(fieldPath));
  }
  public VarFluent.FieldrefNested<A> withNewFieldref() {
    return new VarFluentImpl.FieldrefNestedImpl();
  }
  public VarFluent.FieldrefNested<A> withNewFieldrefLike(FieldSelector item) {
    return new VarFluentImpl.FieldrefNestedImpl(item);
  }
  public VarFluent.FieldrefNested<A> editFieldref() {
    return withNewFieldrefLike(getFieldref());
  }
  public VarFluent.FieldrefNested<A> editOrNewFieldref() {
    return withNewFieldrefLike(getFieldref() != null ? getFieldref(): new FieldSelectorBuilder().build());
  }
  public VarFluent.FieldrefNested<A> editOrNewFieldrefLike(FieldSelector item) {
    return withNewFieldrefLike(getFieldref() != null ? getFieldref(): item);
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * This method has been deprecated, please use method buildObjref instead.
   * @return The buildable object.
   */
  @Deprecated
  public Target getObjref() {
    return this.objref!=null ?this.objref.build():null;
  }
  public Target buildObjref() {
    return this.objref!=null ?this.objref.build():null;
  }
  public A withObjref(Target objref) {
    _visitables.get("objref").remove(this.objref);
    if (objref!=null){ this.objref= new TargetBuilder(objref); _visitables.get("objref").add(this.objref);} else { this.objref = null; _visitables.get("objref").remove(this.objref); } return (A) this;
  }
  public Boolean hasObjref() {
    return this.objref != null;
  }
  public VarFluent.ObjrefNested<A> withNewObjref() {
    return new VarFluentImpl.ObjrefNestedImpl();
  }
  public VarFluent.ObjrefNested<A> withNewObjrefLike(Target item) {
    return new VarFluentImpl.ObjrefNestedImpl(item);
  }
  public VarFluent.ObjrefNested<A> editObjref() {
    return withNewObjrefLike(getObjref());
  }
  public VarFluent.ObjrefNested<A> editOrNewObjref() {
    return withNewObjrefLike(getObjref() != null ? getObjref(): new TargetBuilder().build());
  }
  public VarFluent.ObjrefNested<A> editOrNewObjrefLike(Target item) {
    return withNewObjrefLike(getObjref() != null ? getObjref(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VarFluentImpl that = (VarFluentImpl) o;
    if (fieldref != null ? !fieldref.equals(that.fieldref) :that.fieldref != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (objref != null ? !objref.equals(that.objref) :that.objref != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fieldref,  name,  objref,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fieldref != null) { sb.append("fieldref:"); sb.append(fieldref + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (objref != null) { sb.append("objref:"); sb.append(objref + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class FieldrefNestedImpl<N> extends FieldSelectorFluentImpl<VarFluent.FieldrefNested<N>> implements VarFluent.FieldrefNested<N>,Nested<N>{
    FieldrefNestedImpl(FieldSelector item) {
      this.builder = new FieldSelectorBuilder(this, item);
    }
    FieldrefNestedImpl() {
      this.builder = new FieldSelectorBuilder(this);
    }
    FieldSelectorBuilder builder;
    public N and() {
      return (N) VarFluentImpl.this.withFieldref(builder.build());
    }
    public N endFieldref() {
      return and();
    }
    
  }
  class ObjrefNestedImpl<N> extends TargetFluentImpl<VarFluent.ObjrefNested<N>> implements VarFluent.ObjrefNested<N>,Nested<N>{
    ObjrefNestedImpl(Target item) {
      this.builder = new TargetBuilder(this, item);
    }
    ObjrefNestedImpl() {
      this.builder = new TargetBuilder(this);
    }
    TargetBuilder builder;
    public N and() {
      return (N) VarFluentImpl.this.withObjref(builder.build());
    }
    public N endObjref() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-kustomize-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/VarFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VarFluentImpl<A extends VarFluent<A>> extends BaseFluent<A> implements VarFluent<A>{
  public VarFluentImpl() {
  }
  public VarFluentImpl(Var instance) {
    if (instance != null) {
      this.withFieldref(instance.getFieldref());
      this.withName(instance.getName());
      this.withObjref(instance.getObjref());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private FieldSelectorBuilder fieldref;
  private String name;
  private TargetBuilder objref;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildFieldref instead.
   * @return The buildable object.
   */
  @Deprecated
  public FieldSelector getFieldref() {
    return this.fieldref!=null ?this.fieldref.build():null;
  }
  public FieldSelector buildFieldref() {
    return this.fieldref!=null ?this.fieldref.build():null;
  }
  public A withFieldref(FieldSelector fieldref) {
    _visitables.get("fieldref").remove(this.fieldref);
    if (fieldref!=null){ this.fieldref= new FieldSelectorBuilder(fieldref); _visitables.get("fieldref").add(this.fieldref);} else { this.fieldref = null; _visitables.get("fieldref").remove(this.fieldref); } return (A) this;
  }
  public Boolean hasFieldref() {
    return this.fieldref != null;
  }
  public A withNewFieldref(String fieldPath) {
    return (A)withFieldref(new FieldSelector(fieldPath));
  }
  public VarFluentImpl.FieldrefNested<A> withNewFieldref() {
    return new VarFluentImpl.FieldrefNestedImpl();
  }
  public VarFluentImpl.FieldrefNested<A> withNewFieldrefLike(FieldSelector item) {
    return new VarFluentImpl.FieldrefNestedImpl(item);
  }
  public VarFluentImpl.FieldrefNested<A> editFieldref() {
    return withNewFieldrefLike(getFieldref());
  }
  public VarFluentImpl.FieldrefNested<A> editOrNewFieldref() {
    return withNewFieldrefLike(getFieldref() != null ? getFieldref(): new FieldSelectorBuilder().build());
  }
  public VarFluentImpl.FieldrefNested<A> editOrNewFieldrefLike(FieldSelector item) {
    return withNewFieldrefLike(getFieldref() != null ? getFieldref(): item);
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * This method has been deprecated, please use method buildObjref instead.
   * @return The buildable object.
   */
  @Deprecated
  public Target getObjref() {
    return this.objref!=null ?this.objref.build():null;
  }
  public Target buildObjref() {
    return this.objref!=null ?this.objref.build():null;
  }
  public A withObjref(Target objref) {
    _visitables.get("objref").remove(this.objref);
    if (objref!=null){ this.objref= new TargetBuilder(objref); _visitables.get("objref").add(this.objref);} else { this.objref = null; _visitables.get("objref").remove(this.objref); } return (A) this;
  }
  public Boolean hasObjref() {
    return this.objref != null;
  }
  public VarFluentImpl.ObjrefNested<A> withNewObjref() {
    return new VarFluentImpl.ObjrefNestedImpl();
  }
  public VarFluentImpl.ObjrefNested<A> withNewObjrefLike(Target item) {
    return new VarFluentImpl.ObjrefNestedImpl(item);
  }
  public VarFluentImpl.ObjrefNested<A> editObjref() {
    return withNewObjrefLike(getObjref());
  }
  public VarFluentImpl.ObjrefNested<A> editOrNewObjref() {
    return withNewObjrefLike(getObjref() != null ? getObjref(): new TargetBuilder().build());
  }
  public VarFluentImpl.ObjrefNested<A> editOrNewObjrefLike(Target item) {
    return withNewObjrefLike(getObjref() != null ? getObjref(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VarFluentImpl that = (VarFluentImpl) o;
    if (!java.util.Objects.equals(fieldref, that.fieldref)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(objref, that.objref)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fieldref,  name,  objref,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fieldref != null) { sb.append("fieldref:"); sb.append(fieldref + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (objref != null) { sb.append("objref:"); sb.append(objref + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class FieldrefNestedImpl<N> extends FieldSelectorFluentImpl<VarFluentImpl.FieldrefNested<N>> implements VarFluentImpl.FieldrefNested<N>,Nested<N>{
    FieldrefNestedImpl(FieldSelector item) {
      this.builder = new FieldSelectorBuilder(this, item);
    }
    FieldrefNestedImpl() {
      this.builder = new FieldSelectorBuilder(this);
    }
    FieldSelectorBuilder builder;
    public N and() {
      return (N) VarFluentImpl.this.withFieldref(builder.build());
    }
    public N endFieldref() {
      return and();
    }
    
  }
  class ObjrefNestedImpl<N> extends TargetFluentImpl<VarFluentImpl.ObjrefNested<N>> implements VarFluentImpl.ObjrefNested<N>,Nested<N>{
    ObjrefNestedImpl(Target item) {
      this.builder = new TargetBuilder(this, item);
    }
    ObjrefNestedImpl() {
      this.builder = new TargetBuilder(this);
    }
    TargetBuilder builder;
    public N and() {
      return (N) VarFluentImpl.this.withObjref(builder.build());
    }
    public N endObjref() {
      return and();
    }
    
  }
  
}
